<?php
// $Id: uc_vat.theme.inc,v 1.2 2010/03/23 13:02:30 longwave Exp $

/**
 * Format the cart contents table including VAT information on the checkout page.
 *
 * @param $show_subtotal
 *   TRUE or FALSE indicating if you want a subtotal row displayed in the table.
 * @param $order
 *   An order object to use for tax rule evaluation.
 * @return
 *   The HTML output for the cart review table.
 *
 * @ingroup themeable
 */
function theme_uc_vat_cart_review_table($show_subtotal = TRUE, $order = NULL) {
  $taxes = uc_vat_exclude_vat() ? array() : uc_vat_load_order_taxes($order);

  $tax_subtotal = 0;
  $subtotal = 0;
  $tax_name = variable_get('uc_vat_name', 'VAT');

  // Set up table header.
  $header = array(
    array('data' => t('Qty'), 'class' => 'qty'),
    array('data' => t('Products'), 'class' => 'products'),
  );
  if ($taxes) {
    if (variable_get('uc_vat_hide_checkout_exclusive', FALSE)) {
      $header[] = array('data' => t('incl. !tax', array('!tax' => $tax_name)), 'class' => 'price vat', 'style' => 'white-space: nowrap;');
    }
    else {
      $header[] = array('data' => t('Price excl. !tax', array('!tax' => variable_get('uc_vat_name', 'VAT'))), 'class' => 'price excl-vat', 'style' => 'white-space: nowrap;');
      $header[] = array('data' => $tax_name, 'class' => 'price vat');
    }
  }
  $header[] = array('data' => t('Price'), 'class' => 'price');

  // Set up table rows.
  $contents = uc_cart_get_contents();
  foreach ($contents as $item) {
    $node = node_load($item->nid);
    $price_info = array(
      'price' => $item->price,
      'qty' => $item->qty,
    );
    $context = array(
      'type' => $order ? 'order_product' : 'cart_item',
      'revision' => 'altered',
      'subject' => array(
        'order' => $order,
        'cart' => $contents,
        'cart_item' => $item,
        'product' => $item,
        'node' => $node,
      ),
    );

    $total = uc_price($price_info, $context);
    $tax_total = 0;
    foreach ($taxes as $tax) {
      if (in_array($node->type, $tax->taxed_product_types) && ($tax->shippable == 0 || $node->shippable == 1)) {
        $tax_total += $total - $total / (1 + $tax->rate);
      }
    }
    $price = $total - $tax_total;
    $tax_subtotal += $tax_total;
    $subtotal += $total;

    $description = check_plain($item->title);
    foreach (module_implements('cart_item_description') as $module) {
      $description .= module_invoke($module, 'cart_item_description', $item);
    }

    // Remove node from context to prevent the price from being altered.
    unset($context['subject']);
    $context['type'] = 'amount';
    $context['revision'] = 'themed-original';

    $row = array(
      array('data' => t('@qty&times;', array('@qty' => $item->qty)), 'class' => 'qty'),
      array('data' => $description, 'class' => 'products'),
    );
    if ($taxes) {
      if (!variable_get('uc_vat_hide_checkout_exclusive', FALSE)) {
        $row[] = array('data' => uc_price($price, $context), 'class' => 'price excl-vat');
      }
      $row[] = array('data' => uc_price($tax_total, $context), 'class' => 'price vat');
    }
    $row[] = array('data' => uc_price($total, $context), 'class' => 'price');
    $rows[] = $row;
  }

  // Add the subtotals as the final row.
  if ($show_subtotal) {
    $context = array(
      'type' => 'amount',
      'revision' => 'themed-original',
    );

    $row = array();
    $title = '<span id="subtotal-title">' . t('Subtotal:') . '</span> ';
    if ($taxes) {
      if (variable_get('uc_vat_hide_checkout_exclusive', FALSE)) {
        $row[] = array('data' => $title . uc_price($tax_subtotal, $context), 'colspan' => count($header) - 1, 'class' => 'subtotal vat');
      }
      else {
        $row[] = array('data' => $title . uc_price($subtotal - $tax_subtotal, $context), 'colspan' => count($header) - 2, 'class' => 'subtotal excl-vat');
        $row[] = array('data' => uc_price($tax_subtotal, $context), 'class' => 'subtotal vat');
      }
      $row[] = array('data' => uc_price($subtotal, $context), 'class' => 'subtotal');
    }
    else {
      $row[] = array('data' => $title . uc_price($subtotal, $context), 'colspan' => count($header), 'class' => 'subtotal');
    }

    $rows[] = array('data' => $row, 'class' => 'subtotal');
  }

  return theme('table', $header, $rows, array('class' => 'cart-review'));
}
